# Generated by Django 2.1.2 on 2018-11-05 23:15

from django.conf import settings
import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djams', '0008_adm_team_team_members'),
    ]

    operations = [
        migrations.AddField(
            model_name='adm_devteam',
            name='team_members',
            field=models.ManyToManyField(related_name='devteam_members_users', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='adm_app',
            name='app_thumbnail',
            field=models.ImageField(storage=django.core.files.storage.FileSystemStorage(location='C:\\Users\\eburm\\Documents\\MEGA\\platform_code\\admin_portal\\../media'), upload_to='app_thumbnails'),
        ),
    ]
